@@ -13,6 +13,8 @@ from ambient_package_update.metadata.ruff_ignored_inspection import (
     RuffIgnoredInspection,
 )
 
+claim = "Python toolbox of Ambient Digital containing an abundance of useful tools and gadgets."
+
 METADATA = PackageMetadata(
     package_name="ambient-toolbox",
     github_package_group="ambient-innovation",
@@ -24,12 +26,13 @@ METADATA = PackageMetadata(
         ),
     ],
     maintainer=PackageMaintainer(name="Ambient Digital", url="https://ambient.digital/", email="hello@ambient.digital"),
-    min_coverage=73.21,
+    min_coverage=73.17,
     development_status="5 - Production/Stable",
     license=LICENSE_MIT,
     license_year=2012,
+    claim=claim,
     readme_content=ReadmeContent(
-        tagline="Python toolbox of Ambient Digital containing an abundance of useful tools and gadgets.",
+        tagline=claim,
     ),
     dependencies=[
         f"Django>={SUPPORTED_DJANGO_VERSIONS[0]}",
