@@ -1,10 +1,9 @@
 from pathlib import Path
-from typing import Union
 
 from django.conf import settings
 
 
-def get_autodiscover_enabled() -> Union[Path, str]:
+def get_autodiscover_enabled() -> Path | str:
     """
     Switch to enable or disable function autodiscovery.
     Since the registry will be called on every request, we want to save overhead for projects that don't use it.
@@ -19,7 +18,7 @@ def get_namespaces() -> list[str]:
     return getattr(settings, "AMBIENT_TOOLBOX_NAMESPACES", [])
 
 
-def get_autodiscover_app_base_path() -> Union[Path, str]:
+def get_autodiscover_app_base_path() -> Path | str:
     """
     Base path of the application autodiscover should look for registered handlers.
     """
