@@ -1,7 +1,4 @@
-from typing import Union
-
-
-def unique_append_to_inner_list(*, data: dict, key: Union[str, int], value) -> dict:
+def unique_append_to_inner_list(*, data: dict, key: str | int, value) -> dict:
     """
     Inserts "value" in the dictionary "data" on "key".
     If "key" doesn't exist yet, it will create a new list containing "value".
