@@ -1,9 +1,9 @@
 from django.core.management.base import BaseCommand
 
-from ambient_toolbox.tests.structure_validator.test_structure_validator import TestStructureValidator
+from ambient_toolbox.tests.structure_validator.test_structure_validator import StructureTestValidator
 
 
 class Command(BaseCommand):
     def handle(self, *args, **options):
-        service = TestStructureValidator()
+        service = StructureTestValidator()
         service.process()
