@@ -1,5 +1,6 @@
 import warnings
-from typing import TYPE_CHECKING, Callable
+from collections.abc import Callable
+from typing import TYPE_CHECKING
 
 from .current_request import CurrentRequestMiddleware
 
